@@ -7,8 +7,6 @@ Released under the GPL-3 Gnu Public License.
 """
 
 import click
-import os
-import sys
 import dhfortran.compilers as cmplrs
 import dhfortran.cli as cli
 import dhfortran.targets as targets
@@ -18,8 +16,8 @@ import dhfortran.targets as targets
 @click.pass_context
 def dh_fortran(ctx):
     cli.verbose_print("dh_fortran called")
-    # ensure that ctx.obj exists and is a dict (in case `cli()` is called
-    # by means other than the `if` block below)
+    # breakpoint()    # ensure that ctx.obj exists and is a dict
+    # (in case `cli()` is called by means other than the `if` block below)
     ctx.ensure_object(dict)
 
 
@@ -49,51 +47,136 @@ def get_f77_flags(f77):
 @dh_fortran.command("get_ld_flags")
 @click.option("--fc", default=None, help="Fortran compiler")
 # @cli.debhelper_common_args
-def get_fc_flags(fc):
+def get_ld_flags(fc):
     """
     Returns set of flags to be set , either passed as FCFLAGS to another
     """
     cli.verbose_print("dh_fortran get_ld_flags called")
     cli.validate_compiler(fc)
-    click.echo(cmplrs.get_ld_flags(fc))
+    flavor, arch = cmplrs.get_fc_flavor_arch(fc)
+    click.echo(cmplrs.get_ld_flags(flavor, arch))
+
 
 @dh_fortran.command("get_fc_default", help="Returns default Fortran flavor")
+@click.option("--fc", default=None, help="Fortran compiler")
 @click.pass_context
-def get_fc_default(ctx):
+def get_fc_default(ctx, fc):
     """
     Details on get_fc_default
     """
     cli.verbose_print("dh_fortran get_fc_default called")
-    click.echo(cmplrs.get_fc_default())
+    cli.validate_compiler(fc)
+    click.echo(cmplrs.get_fc_default(fc))
 
 
 @dh_fortran.command("get_fc_optional", help="Returns list of optional Fortran flavors")
+@click.option("--fc", default=None, help="Fortran compiler")
 @click.pass_context
-def get_fc_optional(ctx):
+def get_fc_optional(ctx, fc):
     cli.verbose_print("dh_fortran get_fc_optional called")
-    click.echo(cmplrs.get_fc_optional())
+    cli.validate_compiler(fc)
+    flavor, arch = cmplrs.get_fc_flavor_arch(fc)
+    click.echo(cmplrs.get_fc_optional(flavor))
 
 
-@dh_fortran.command("get_flibdir", help="Returns flibdir for a given flavor")
+@dh_fortran.command("get_flibdir", help="Returns flibdir for a given compiler")
 @click.pass_context
-@click.option("--flavor", help="Fortran flavor (eg gfortran-15, flang-21)")
-def get_flibdir(ctx, flavor):
+@click.option("--fc", default=None, help="Fortran compiler (eg gfortran-15, flang-21")
+@click.option(
+    "--prepend",
+    "-L",
+    help="Prepend -L to directories as needed",
+    is_flag=True,
+    default=False,
+)
+def get_flibdir(ctx, fc, prepend):
     cli.verbose_print("dh_fortran get_flibdir called")
-    cli.validate_flavor(flavor)
-    click.echo(cmplrs.get_flibdir(flavor))
-
-
-@dh_fortran.command("get_fmoddir", help="Returns fmoddir for a given flavor")
-@click.option("--flavor", help="Fortran flavor (eg gfortran-15, flang-21)")
-@click.pass_context
-def get_fmoddir(ctx, flavor):
-    cli.verbose_print("dh_fortran get_fmoddir called")
-    cli.validate_flavor(flavor)
-    click.echo(cmplrs.get_fmoddir(flavor))
+    cli.validate_compiler(fc)
+    flavor, arch = cmplrs.get_fc_flavor_arch(fc)
+    prefix = "-L" if prepend else ""
+    click.echo(f"{prefix}{cmplrs.get_flibdir(flavor,arch)}")
 
 
 @dh_fortran.command(
-    "get_fc_exe", help="Return Fortran executable for specified (or default) flavor"
+    "get_flibdirs", help="Returns compatible flibdirs for a given compiler"
+)
+@click.pass_context
+@click.option("--fc", default=None, help="Fortran compiler (eg gfortran-15, flang-21")
+@click.option(
+    "--prepend",
+    "-L",
+    help="Prepend -L to directories as needed",
+    is_flag=True,
+    default=False,
+)
+def get_flibdirs(ctx, fc, prepend):
+    cli.verbose_print("dh_fortran get_flibdirs called")
+    cli.validate_compiler(fc)
+    flavor, arch = cmplrs.get_fc_flavor_arch(fc)
+    libdirs = cmplrs.get_flibdirs(flavor, arch)
+    prefix = "-L" if prepend else ""
+    click.echo(" ".join([f"{prefix}{fl}" for fl in libdirs]))
+
+
+@dh_fortran.command("get_fmoddir", help="Returns fmoddir for a given compiler")
+@click.option("--fc", default=None, help="Fortran compiler")
+@click.option("--flavor", help="Fortran flavor (eg gfortran-15, flang-21)")
+#              deprecate="--flavor is deprecated in favour of --fc")
+@click.option(
+    "--prepend",
+    "-I",
+    help="Prepend -I or -M to directories as needed",
+    is_flag=True,
+    default=False,
+)
+@click.pass_context
+def get_fmoddir(ctx, flavor, fc, prepend):
+    cli.verbose_print("dh_fortran get_fmoddir called")
+    cli.validate_compiler(fc)
+    flavor, arch = cmplrs.get_fc_flavor_arch(flavor if fc is None else fc)
+    # May be "-I" or "-module " depending on compiler
+    prefix = ""
+    if prepend:
+        prefix = (
+            cmplrs.compilers[flavor]["mod_arg"]
+            if "mod_arg" in cmplrs.compilers[flavor]
+            else "-I"
+        )
+    click.echo(f"{prefix}{cmplrs.get_fmoddir(flavor,arch)}")
+
+
+@dh_fortran.command(
+    "get_fmoddirs", help="Returns compatible fmoddirs for a given compiler"
+)
+@click.option("--fc", help="Fortran compiler (eg gfortran-15, flang-21)")
+@click.option(
+    "--prepend",
+    "-I",
+    help="Prepend -I or -M to directories as needed",
+    is_flag=True,
+    default=False,
+)
+@click.pass_context
+def get_fmoddirs(ctx, fc, prepend):
+    cli.verbose_print("dh_fortran get_fmoddirs called")
+    cli.validate_compiler(fc)
+    flavor, arch = cmplrs.get_fc_flavor_arch(fc)
+    # TODO. May be "-I" or "-M" depending on compiler
+    moddirs = cmplrs.get_fmoddirs(flavor, arch)
+    prefix = ""
+    if prepend:
+        prefix = (
+            cmplrs.compilers[flavor]["mod_arg"]
+            if "mod_arg" in cmplrs.compilers[flavor]
+            else "-I"
+        )
+    click.echo(" ".join([f"{prefix}{moddir}" for moddir in moddirs]))
+
+
+@dh_fortran.command(
+    "get_fc_exe",
+    help="Return Fortran executable for specified (or default) flavor",
+    deprecated="MAY BE  DEPRECATED IN FINAL API",
 )
 @click.option("--flavor", help="Fortran flavor (eg gfortran-15, flang-21)")
 @click.pass_context
@@ -104,23 +187,30 @@ def get_fc_exe(ctx, flavor):
 
 
 @dh_fortran.command("get_abi_vendor", help="Returns ABI name for a given compiler")
-@click.option("--flavor", help="Fortran flavor (eg gfortran-15, flang-21)")
+@click.option("--fc", help="Fortran compiler  (eg gfortran-15, flang-21)")
 @click.pass_context
-def get_abi_vendor(ctx, flavor):
+def get_abi_vendor(ctx, fc):
     cli.verbose_print("dh_fortran get_abi_vendor called")
-    cli.validate_flavor(flavor)
-    return cmplrs.get_abi_vendor(flavor)
+    cli.validate_compiler(fc)
+    flavor, arch = cmplrs.get_fc_flavor_arch(fc)
+    click.echo(cmplrs.get_abi_vendor(flavor))
 
 
 @dh_fortran.command(
     "get_env",
     help="Return set of environment flags to execute  debian/rules targets with",
 )
-@click.option("--flavor", help="Fortran flavor (eg gfortran-15, flang-21)")
-def get_env(flavor: str):
-    cli.verbose_print("dh_fortran get_env called")
-    cli.validate_flavor(flavor)
-    click.echo(cmplrs.get_env(flavor))
+@click.option("--fc", default=None, help="Fortran compiler")
+@click.option("--save", default=False, is_flag=True, hidden=True)
+def get_env(fc: str, save: bool):
+    cli.debug_print("dh_fortran get_env called")
+    cli.validate_compiler(fc)
+    flavor, arch = cmplrs.get_fc_flavor_arch(fc)
+    if save:
+        with open(".debhelper/fc_env", "w") as f:
+            print(cmplrs.get_env(flavor), file=f)
+    else:
+        click.echo(cmplrs.get_env(flavor))
 
 
 ##
@@ -130,14 +220,14 @@ def get_env(flavor: str):
 
 @cli.debhelper_common_args
 @dh_fortran.command("clean", help="Execute Fortran-specific clean actions")
-@click.option("--fc-default", "-d", help="Act on named package")
-@click.option("--fc-optional", help="Act on named package")
-def clean(fc_default, fc_optional):
+def clean():
     targets.clean()
 
 
 @cli.debhelper_common_args
-@dh_fortran.command("configure", help="Execute configure actions for each Fortran flavor")
+@dh_fortran.command(
+    "configure", help="Execute configure actions for each Fortran flavor"
+)
 def configure():
     targets.configure()
 
