@@ -6,11 +6,19 @@ Copyright (C) 2025 Alastair McKinstry <mckinstry@debian.org>
 Released under the GPL-3 Gnu Public License.
 """
 
-import dhfortran.cli
+import dhfortran.cli as cli
 
 
-def test_cli():
+def test_validate_flavor():
     print("DEBUG: test_cli called")
+    cli.validate_flavor(None)    
+
+def test_validate_fc_none():
+    cli.validate_compiler(None)
+    
+def test_get_env():
+    pass
+
 
 
 if __name__ == "__main__":
