@@ -8,7 +8,7 @@ Released under the GPL-3 Gnu Public License.
 
 from click.testing import CliRunner
 from dhfortran.lib import dh_fortran_lib, get_soname
-from dhfortran.compilers import libdir
+from dhfortran.compilers import multiarch
 import dhfortran.debhelper as dh
 import dhfortran.tests.helpers as helpers
 import pytest
@@ -21,6 +21,7 @@ def set_env():
 
 def test_get_soname():
     """ soname helper """
+    libdir= f"/usr/lib/{multiarch}"
     (major, soname,ext ) = get_soname(f"{libdir}/libm.so.6")
     assert soname == "libm.so.6"
     assert major == "6"
@@ -45,6 +46,7 @@ def test_dh_fortran_lib_files_nopkg():
     # helpers.chdir_to_test('tests/pkg')
     runner = CliRunner()
     result = runner.invoke(dh_fortran_lib, ["debian/tmp/foo"])
+    print (result.output)
     assert result.exit_code == 0
     # assert result.output == 'Hello Peter!\n'
 
